from setuptools import setup

setup(name='mypackage_xavier',
version='0.1',
description='Testing installation of Package',
author='auth',
author_email='author@email.com',
license='MIT',
packages=['mypackage_xavier'],
zip_safe=False)